@@ -30,17 +30,17 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	label->setContextMenuPolicy(Qt::NoContextMenu);
 	label->setAlignment(Qt::AlignCenter);
 
-	
+
 	for (int i = 0; i < 12; i++) {
 		QString text ('0' + i + 1);
 
 		if (i == 9) {
 			text = "Ok";
 			imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_accept.png"),
-			imageButton[i] ->setFixedHeight(60);
+			imageButton[i] ->setFixedHeight(70);
 			imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 			imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-			imageButton[i] ->setIconSize(QSize(20, 20));
+			//imageButton[i] ->setIconSize(QSize(20, 20));
 			componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 			//signalMapper->setMapping(imageButton[i], text);
@@ -50,10 +50,10 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 			if (i == 10) {
 				text = "0";
 				imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-				imageButton[i] ->setFixedHeight(60);
+				imageButton[i] ->setFixedHeight(70);
 				imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 				imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-				imageButton[i] ->setIconSize(QSize(20, 20));
+				//imageButton[i] ->setIconSize(QSize(20, 20));
 				componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 				signalMapper->setMapping(imageButton[i], text);
@@ -63,10 +63,10 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 				if (i == 11) {
 					text = "Clear";
 					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_clear.png"),
-					imageButton[i] ->setFixedHeight(60);
+					imageButton[i] ->setFixedHeight(70);
 					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-					imageButton[i] ->setIconSize(QSize(20, 20));
+					//imageButton[i] ->setIconSize(QSize(20, 20));
 					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 					//signalMapper->setMapping(imageButton[i], text);
@@ -74,10 +74,10 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 					QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(clearS()));
 				} else {
 					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-					imageButton[i] ->setFixedHeight(60);
+					imageButton[i] ->setFixedHeight(70);
 					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
 					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-					imageButton[i] ->setIconSize(QSize(20, 20));
+					//imageButton[i] ->setIconSize(QSize(20, 20));
 					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 					signalMapper->setMapping(imageButton[i], text);
