@@ -8,16 +8,16 @@
 // TODO support for portrain
 // TODO final images
  * TODO strong encryption with characters
- * TODO ask for second password when creating a db
  * TODO check that export images get the right size
  * TODO image size when no credit card (axa)
  * TODO free list resources
  * TODO after change type it is not refreshed on list
- * TODO implements URL to click on
  * TODO implements copy of information field (and images?)
- * TODO avoid invalid empty password
- * TODO allow to delete database
  * TODO allow to change password
+ * TODO use hilton notifications and banner???
+ * TODO check types on import
+ * TODO sort after insert new card
+ * TODO add warn message when import and export!
  */
 
 #include "eWallet.h"
@@ -197,6 +197,22 @@ void eWallet::lockWallet () {
 	askPassword ();
 }
 
+void eWallet::deleteDB () {
+	if (messageBox.isNull()) {
+		messageBox = new QMessageBox(this);
+		int b = messageBox->information(this, "Wallet", "Are you sure you want to remove all your data? You will lost all your data", QMessageBox::Yes, QMessageBox::No);
+		if (b == QMessageBox::Yes) {
+			::dbManager->reset ();
+
+			if (!loginDialogDlg.isNull()) {
+				loginDialogDlg->resetF ();
+			}
+		}
+	}
+	delete messageBox;
+	messageBox = 0;
+}
+
 bool eWallet::openDataBase (QString pas)
 {
 	bool res = ::dbManager->openDB(pas);
@@ -334,6 +350,27 @@ bool sortTargetsDES (const Target * f, const Target * g) {
 	return f->name.toLower() > g->name.toLower();
 }
 
+QPixmap eWallet::getImage (Target * target) {
+	QPixmap image;
+	if (target->getPictureSmall() != NULL) {
+		image = QPixmap::fromImage (*target->getPictureSmall());
+
+		// at this moment we don't need anymore original images!
+		target->freeResources();
+	} else {
+		QString tmp = ":/resources/empty_";
+		tmp += target->type.simplified().replace(' ', '_');
+		tmp += ".png";
+
+		if (QResource (tmp).isValid()) {
+			image = QPixmap (tmp);
+		}
+		else {
+			image = QPixmap (":/resources/empty_Others.png");
+		}
+	}
+	return image;
+}
 void eWallet::showTargets(bool reset)
 {
 	// Clean previous items from the layout
@@ -351,30 +388,14 @@ void eWallet::showTargets(bool reset)
 	else
 		qSort (list.begin(),list.end(),sortTargetsDES);
 
+	fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
+	//fnListWidget->setContentsMargins(10, 1, 0, 1);
+
 	for (int i = 0; i < list.size (); i++) {
 		Target * target = list.at(i);
 
-		QPixmap image;
-		if (target->getPictureSmall() != NULL) {
-			image = QPixmap::fromImage (*target->getPictureSmall());
-
-			// at this moment we don't need anymore original images!
-			target->freeResources();
-		} else {
-			QString tmp = ":/resources/empty_";
-			tmp += target->type.simplified().replace(' ', '_');
-			tmp += ".png";
-
-			if (QResource (tmp).isValid()) {
-				image = QPixmap (tmp);
-			}
-			else {
-				image = QPixmap (":/resources/empty_Others.png");
-			}
-		}
-
-		QListWidgetItem* listitem = new QListWidgetItem(image, target->name, fnListWidget);
-
+		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
+		//listitem->set(target->getSummary());
 		fnListWidget->addItem(listitem);
 		
 //		QObject::connect(listitem, SIGNAL(viewTarget(Target*)),
@@ -387,7 +408,9 @@ void eWallet::showTargets(bool reset)
 
 	filterBy(currentFilter);
 
-	update();
+	fnListWidget->setCurrentRow(0);
+
+	//update();
 }
 
 void eWallet::createMenu()
@@ -408,13 +431,21 @@ void eWallet::sort()
 	showTargets(false);
 }
 
-bool eWallet::_insertTarget(Target* target)
+bool eWallet::__insertTarget(Target* target)
 {
 	if (::dbManager->insertTarget(target)) {
 		//qDebug () << "Adding new item";
 		::dbManager->updateFields (target);
 		
 		target->freeFieldList();
+		return true;
+	}
+	return false;
+}
+
+bool eWallet::_insertTarget(Target* target)
+{
+	if (__insertTarget(target)) {
 
 		list.append(target);
 
@@ -423,26 +454,7 @@ bool eWallet::_insertTarget(Target* target)
 //		else
 //			qSort (list.begin(),list.end(),sortTargetsDES);
 
-		QPixmap image;
-		if (target->getPictureSmall() != NULL) {
-			image = QPixmap::fromImage (*target->getPictureSmall());
-
-			// at this moment we don't need anymore original images!
-			target->freeResources();
-		} else {
-			QString tmp = ":/resources/empty_";
-			tmp += target->type.simplified().replace(' ', '_');
-			tmp += ".png";
-
-			if (QResource (tmp).isValid()) {
-				image = QPixmap (tmp);
-			}
-			else {
-				image = QPixmap (":/resources/empty_Others.png");
-			}
-		}
-
-		QListWidgetItem* listitem = new QListWidgetItem(image, target->name, fnListWidget);
+		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
 
 		int pos = list.indexOf(target);
 		qDebug () << "position of new " << pos << " OF " << list.size ();
@@ -463,26 +475,15 @@ bool eWallet::_insertTarget(Target* target)
 bool eWallet::_deleteTarget(Target* target)
 {
 	int i = list.indexOf(target);
-	qDebug () << "DELETE ON " << i;
+	//qDebug () << "DELETE ON " << i;
 	if (::dbManager->deleteTarget(target)) {
 		list.removeAt(i);
 
-		//QFNListItem* listitem = (QFNListItem*)fnListWidget->currentItem(); //itemAt (row);
-		//QListWidgetItem * listItem = fnListWidget->currentItem();
-//		//disconnect(obj, SIGNAL(destroyed(QObject*)),               this, SLOT(windowDestroyed(QObject*)));
-//		QObject::disconnect(listitem, SIGNAL(viewTarget(Target*)),
-//                      this, SLOT(viewTarget(Target*)));
-//		QObject::disconnect(listitem, SIGNAL(editTarget(Target*)),
-//                      this, SLOT(editTarget(Target*)));
-//		QObject::disconnect(listitem, SIGNAL(deleteTarget(Target*)),
-//                      this, SLOT(deleteTarget(Target*)));
-
 		fnListWidget->takeItem(i); //oveItem (row);
 //		target->freeFieldList();
 //		target->freeResources();
 //		delete target;
-		// TODO delete listitem;
-		//update ();
+		delete target;
 		return true;
 	}
 	return false;
@@ -490,7 +491,7 @@ bool eWallet::_deleteTarget(Target* target)
 bool eWallet::_updateTarget(Target* target)
 {
 	int i = list.indexOf(target);
-	qDebug () << "UPDATE ON " << i;
+	//qDebug () << "UPDATE ON " << i;
 
 	if (::dbManager->updateTarget(target)) {
 		::dbManager->updateFields (target);
@@ -508,30 +509,10 @@ bool eWallet::_updateTarget(Target* target)
 bool eWallet::_updateTargetPicture(Target* target)
 {
 	int i = list.indexOf(target);
-	qDebug () << "UPDATE ON " << i;
+	//qDebug () << "UPDATE ON " << i;
 	if (::dbManager->updateTargetPicture(target)) {
-
-		QPixmap image;
-		if (target->getPictureSmall() != NULL) {
-			image = QPixmap::fromImage (*target->getPictureSmall());
-
-			// at this moment we don't need anymore original images!
-			target->freeResources();
-		} else {
-			QString tmp = ":/resources/empty_";
-			tmp += target->type.simplified().replace(' ', '_');
-			tmp += ".png";
-
-			if (QResource (tmp).isValid()) {
-				image = QPixmap (tmp);
-			}
-			else {
-				image = QPixmap (":/resources/empty_Others.png");
-			}
-		}
-
 		QListWidgetItem* listitem = fnListWidget->item (i);
-		listitem->setIcon(image);
+		listitem->setIcon(getImage(target));
 		return true;
 	}
 	return false;
@@ -698,7 +679,7 @@ void eWallet::import() {
 						  target->fields.append(field);
 					  }
 
-					  qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
+					  //qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
 		    	  }
 		    	  else {
 		    		  if (target != NULL && target->fields.size() > 0) {
@@ -715,7 +696,7 @@ void eWallet::import() {
 		    	  i = 0;
 		      }
 
-		      qDebug () << line;
+		      //qDebug () << line;
 		    }
 
 			 if (target != NULL) {
@@ -723,8 +704,9 @@ void eWallet::import() {
 			 }
 		    // Close the file
 		    file.close();
-		  }
 
+		    showTargets (true);
+		  }
 	}
 }
 
@@ -829,103 +811,13 @@ void eWallet::askPassword () {
 	
 	menuBar()->clear();
 
-//	do {
-		if (loginDialogDlg.isNull()) {
-			loginDialogDlg = new LoginDialog(this);
-			setCentralWidget(loginDialogDlg);
-			loginDialogDlg->setFocus ();
-//	#if defined(Q_OS_WIN32)
-//			loginDialogDlg->setFixedSize(640,480);
-//	#elif defined(Q_WS_HILDON)
-//			loginDialogDlg->setMinimumSize(size().width(),size().height()-100);
-//	#else
-//			loginDialogDlg->showMaximized();
-//	#endif
-//			loginDialogDlg->setFocus();
-//			loginDialogDlg->exec();
-//			delete loginDialogDlg;
-//			loginDialogDlg = 0;
-		}
-		
-		//qDebug () << "TIME " << times;
-			
-//		if (++times > 3) {
-//			exit(3);
-//		}
-//		else {
-//			if (!::dbManager->isReady ()) {
-//				if (messageBox.isNull()) {
-//					messageBox = new QMessageBox(this);
-//					messageBox->information(this, "Wallet", "Wrong password", QMessageBox::Ok);
-//				}
-//				delete messageBox;
-//				messageBox = 0;
-//			}
-//		}
-//	}
-//	while(!::dbManager->isReady ());
+	if (loginDialogDlg.isNull()) {
+		loginDialogDlg = new LoginDialog(!::dbManager->hasPassword (), this);
+		setCentralWidget(loginDialogDlg);
+		loginDialogDlg->setFocus ();
+	}
 }
 
 void eWallet::about() {
 	QMessageBox::about(this, "About qtWallet", TEXT_ABOUT);
-//	if (aboutDialogDlg.isNull()) {
-//		aboutDialogDlg = new AboutDialog(this);
-//		aboutDialogDlg->showMaximized();
-//#ifdef Q_WS_MAEMO_5
-//		aboutDialogDlg->setAttribute(Qt::WA_Maemo5StackedWindow);
-//#endif
-//		aboutDialogDlg->setAttribute(Qt::WA_DeleteOnClose);
-//        //connect(detailWindowEdit, SIGNAL(destroyed(QObject*)), this, SLOT(windowDestroyed(QObject*)));
-//        aboutDialogDlg->show();
-//
-//	}
 }
-//void AboutDialog::donate() {
-//	QDesktopServices::openUrl( QUrl::fromEncoded("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted" ) );
-//}
-//AboutDialog::AboutDialog(QWidget *paTarget) : QMainWindow(paTarget)
-//{
-//	setContextMenuPolicy(Qt::NoContextMenu);
-//
-//	QWidget * centralWidget = new QWidget(this);
-//	setCentralWidget(centralWidget);
-//
-//	QVBoxLayout * layout = new QVBoxLayout ();
-//
-//	QLabel * label;
-//
-//	label = new QLabel("<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"
-//			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"
-//			"<br>"
-//			"<p>if you think that qtWallet is useful for you, please</p></qt>", this);
-//	label->setContextMenuPolicy(Qt::NoContextMenu);
-//	label->setAlignment(Qt::AlignCenter);
-//	layout->addWidget(label);
-//
-//	QPushButton * donate = new QPushButton(QIcon(":/resources/donate.gif"), "DONATE", this);
-//	donate->setMinimumHeight(100);
-//	//donate->setIconSize(QSize(150,80));
-//	//QHBoxLayout * lah = new QHBoxLayout ();
-//	//lah->addWidget(donate);
-//	layout->addWidget(donate);
-//
-//	QObject::connect(donate, SIGNAL(clicked()), this, SLOT(donate()));
-//
-////	label = new QLabel("<qt><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>", this);
-////	label->setContextMenuPolicy(Qt::NoContextMenu);
-////	label->setOpenExternalLinks (true);
-////	label->setAlignment(Qt::AlignCenter);
-////	label->setMinimumHeight(100);
-////
-////	QPixmap available(":/resources/donate.gif");
-////	label->setPixmap(available);
-//
-////	layout->addWidget(label);
-//
-//	centralWidget->setLayout(layout);
-//}
-//
-//AboutDialog::~AboutDialog()
-//{
-//}
-
